==> haskell-hi-file-parser-0.1.6.0-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hi-file-parser
version:              0.1.6.0
visibility:           public
id:                   hi-file-parser-0.1.6.0-Kz9OMpNhaTAGamzZ55zgew
key:                  hi-file-parser-0.1.6.0-Kz9OMpNhaTAGamzZ55zgew
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Hussein Ait-Lahcen
homepage:             https://github.com/commercialhaskell/hi-file-parser#readme
synopsis:             Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/hi-file-parser/blob/master/README.md>

category:             Development
abi:                  949f71866b252c8759875d53b9d2461e
exposed:              True
exposed-modules:      HiFileParser
hidden-modules:       Paths_hi_file_parser
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hi-file-parser-0.1.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hi-file-parser-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hi-file-parser
hs-libraries:         HShi-file-parser-0.1.6.0-Kz9OMpNhaTAGamzZ55zgew
depends:
    base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0 mtl-2.2.2
    rio-0.1.22.0-Bs52vTxxPqs4Bge6aUVYDC text-1.2.5.0
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hi-file-parser-0.1.6.0-13-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hi-file-parser
version:              0.1.6.0
visibility:           public
id:                   hi-file-parser-0.1.6.0-H6RYZu2vP3JAN9B00fuq4B
key:                  hi-file-parser-0.1.6.0-H6RYZu2vP3JAN9B00fuq4B
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Hussein Ait-Lahcen
homepage:             https://github.com/commercialhaskell/hi-file-parser#readme
synopsis:             Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/hi-file-parser/blob/master/README.md>

category:             Development
abi:                  4276b7ffd7cb8cb17dfb97af77d7e8bf
exposed:              True
exposed-modules:      HiFileParser
hidden-modules:       Paths_hi_file_parser
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hi-file-parser-0.1.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hi-file-parser-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hi-file-parser
hs-libraries:         HShi-file-parser-0.1.6.0-H6RYZu2vP3JAN9B00fuq4B
depends:
    base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0 mtl-2.2.2
    rio-0.1.22.0-CCynOv5jacWCBs6SD5CPpT text-1.2.5.0
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
